@@ -1346,9 +1346,16 @@ class Database:
                 if deri == 'opt':
                     df = df.rename(columns={'contract_month':'year_month'})
                     df['year_month'] = df['year_month'].str.replace('-','', regex=False)
-                    df['year_month'] = pd.to_datetime(df['year_month'], format='%d%b%y')
-                    df = df.sort_values(by=['date','year_month'])
-                    df['year_month'] = df['year_month'].dt.strftime('%b-%y')
+
+                    if 'w' in deri:
+                        df['year_month'] = pd.to_datetime(df['year_month'], format='%d%b%y')
+                        df = df.sort_values(by=['date','year_month'])
+                        df['year_month'] = df['year_month'].dt.strftime('%d%b%y')
+                    else:
+                        df['year_month'] = pd.to_datetime(df['year_month'], format='%b%y')
+                        df = df.sort_values(by=['date', 'year_month'])
+                        df['year_month'] = df['year_month'].dt.strftime('%b-%y')
+
                     if code.isdigit() == True:
                         cols = list(df.columns)
                         cols = [cols[-1]] + cols[:-1]
